@@ -75,7 +75,7 @@ gis_update_login_keyring_password (const gchar *old_, const gchar *new_)
 	SecretValue *new_secret = NULL;
 	GError *error = NULL;
 	
-	service = secret_service_get_sync (0, NULL, &error);
+	service = secret_service_get_sync (SECRET_SERVICE_OPEN_SESSION, NULL, &error);
 	if (service == NULL) {
 		g_warning ("Failed to get secret service: %s", error->message);
 		g_error_free (error);
@@ -92,19 +92,24 @@ gis_update_login_keyring_password (const gchar *old_, const gchar *new_)
 	old_secret = secret_value_new (old_, strlen (old_), "text/plain");
 	new_secret = secret_value_new (new_, strlen (new_), "text/plain");
 
-	g_dbus_connection_call (bus,
-				"org.gnome.keyring",
-				"/org/gnome/keyring",
-			        "org.gnome.keyring.InternalUnsupportedGuiltRiddenInterface",
-				"ChangeWithMasterPassword",
-				g_variant_new ("o@(oayays)@(oayays)",
-					       "/org/freedesktop/secrets/collection/login",
-					       secret_service_encode_dbus_secret (service, old_secret),
-					       secret_service_encode_dbus_secret (service, new_secret)),
-				NULL,
-				0,
-				G_MAXINT,
-				NULL, NULL, NULL);
+	g_dbus_connection_call_sync (bus,
+                                     "org.gnome.keyring",
+                                     "/org/freedesktop/secrets",
+                                     "org.gnome.keyring.InternalUnsupportedGuiltRiddenInterface",
+                                     "ChangeWithMasterPassword",
+                                     g_variant_new ("(o@(oayays)@(oayays))",
+                                                    "/org/freedesktop/secrets/collection/login",
+                                                    secret_service_encode_dbus_secret (service, old_secret),
+                                                    secret_service_encode_dbus_secret (service, new_secret)),
+                                     NULL,
+                                     0,
+                                     G_MAXINT,
+                                     NULL, &error);
+
+        if (error != NULL) {
+          g_warning ("Failed to change keyring password: %s", error->message);
+          g_error_free (error);
+        }
 
 out:
 
